@@ -35,6 +35,7 @@ class Company(IngestedDataType):
     hq: Optional[Location] = None
     locations: Optional[list[Location]] = None
     last_enriched_at: Optional[str] = None
+    telescope_icp: Optional[bool] = None
 
     @staticmethod
     def from_pdl(pdl_input: dict[str, any]) -> Optional['Company']:
@@ -76,5 +77,6 @@ class Company(IngestedDataType):
             founded_year=pdl_input.get('founded'),
             hq=Location.from_pdl(pdl_location) if pdl_location else None,
             locations=[Location.from_pdl(pdl_location)] if pdl_location else None,
-            last_enriched_at=get_current_datetime_aws_format()
+            last_enriched_at=get_current_datetime_aws_format(),
+            telescope_icp=None
         )
