@@ -130,6 +130,7 @@ class Person(IngestedDataType):
     tags: Optional[list[str]] = None
     uploaded_by_user_id: Optional[str] = None
     last_enriched_at: Optional[str] = None
+    telescope_icp: Optional[bool] = None
 
     @staticmethod
     def from_pdl(pdl_input: dict[str, any]) -> Optional['Person']:
@@ -189,5 +190,6 @@ class Person(IngestedDataType):
             ),
             tags=pdl_input.get('tags'),
             uploaded_by_user_id=None,
-            last_enriched_at=get_current_datetime_aws_format()
+            last_enriched_at=get_current_datetime_aws_format(),
+            telescope_icp=None
         )
